@@ -199,6 +199,7 @@ class Ui_MainWindow(object):
         self.override.addItem("")
         self.override.addItem("")
         self.override.addItem("")
+        self.override.addItem("")
         self.override.setItemText(2, "")
         self.horizontalLayout.addWidget(self.override)
         self.medpctoexcel_progressbar = QtWidgets.QProgressBar(self.widget)
@@ -434,9 +435,10 @@ class Ui_MainWindow(object):
         self.datafolder_button.setText(_translate("MainWindow", "Data folder"))
         self.workingVar_label.setText(_translate("MainWindow", "WorkingVar Label (e.g, A)"))
         self.medpctoexcel_button.setText(_translate("MainWindow", "MED-PC to Excel"))
-        self.override.setItemText(0, _translate("MainWindow", "Append"))        
-        self.override.setItemText(1, _translate("MainWindow", "Replace"))
-        self.override.setItemText(2, _translate("MainWindow", "Override"))
+        self.override.setItemText(0, _translate("MainWindow", "New"))
+        self.override.setItemText(1, _translate("MainWindow", "Append"))        
+        self.override.setItemText(2, _translate("MainWindow", "Replace"))
+        self.override.setItemText(3, _translate("MainWindow", "Override"))
         self.medpctoexcel_progressbar.setFormat(_translate("MainWindow", "%p%"))
         self.tabs.setTabText(self.tabs.indexOf(self.genExcel), _translate("MainWindow", "Generate Excel"))
         self.load_datafile.setText(_translate("MainWindow", "Load file"))
@@ -447,7 +449,7 @@ class Ui_MainWindow(object):
         self.label_sessiondur.setText(_translate("MainWindow", "Session duration (mins)"))
         self.plot.setText(_translate("MainWindow", "Plot"))
         self.tabs.setTabText(self.tabs.indexOf(self.dataexplorer), _translate("MainWindow", "Data Explorer"))
-        self.info_label.setText(_translate("MainWindow", "Current version v3.0.3 \n"
+        self.info_label.setText(_translate("MainWindow", "Current version v3.0.7 \n"
 "Created by Yifeng Cheng, Ph.D. \n"
 "Contact:\n"
 "(979)571-8531\n"
@@ -494,14 +496,21 @@ class MyApp (QtWidgets.QMainWindow, Ui_MainWindow):
         #get a list of data file
         datafile_list = files.get_dir_list(display=False)
         self.log.append (self.currentTime+'>>\t'+'Found %s files'%(len(datafile_list)))
-        override = str(self.override.currentText()) 
+        override = str(self.override.currentText())
+        if override == 'New':
+            skipexist = True
+            replace_file = True
+            replace_data  = True
         if override == 'Override':
+            skipexist = False
             replace_file = True
             replace_data  = True
         elif override == 'Replace':
+            skipexist = False
             replace_file = False
             replace_data = True
         elif override == 'Append':
+            skipexist = False
             replace_file = False
             replace_data = False
         
@@ -509,7 +518,7 @@ class MyApp (QtWidgets.QMainWindow, Ui_MainWindow):
         func_out = ''
         for n, f in enumerate(datafile_list):
             #get all data from this session
-            _, func_out = medpc_read(f, working_var_label, override = replace_file, replace = replace_data, log = func_out) #pass TS_df_tree to an anonymous variable
+            _, func_out = medpc_read(f, working_var_label, skipold = skipexist, override = replace_file, replace = replace_data, log = func_out) #pass TS_df_tree to an anonymous variable
             self.medpctoexcel_progressbar.setValue(n/total*100)
         self.medpctoexcel_progressbar.setValue(100)
         self.log.append(func_out)
